<?php
/* ----------------------------
Plugin Name: Disk Player 
Plugin URI: http://srvalle.com/disk-audio-player
Description: Disk Audio Player is a Wordpress plugin to display html5 audio player in your website with unlimited color options and playlists. Main features: HTML5, responsive, retina ready, works on desktop/tablet/phone and playlist with scrollbar.
Version: 1.6.4
Author: Sergio Valle
Author URI: http://srvalle.com/
------------------------------ */

if ( ! class_exists( 'Disk_Player' ) ) :

class Disk_Player {

	////var $update_url = 'http://srvalle.com/plugins/update';

	function __construct() {

		define( 'DISKPLAYER_URL', plugins_url().'/'.basename( dirname( __FILE__ ) ) );
		define( 'DISKPLAYER_DIR', dirname( __FILE__ ) );

        // plugin activation
		register_activation_hook( __FILE__, array( &$this, 'activate_diskplayer' ) );

        // register post type
		add_action( 'init', array( &$this, 'register_post_type_diskplayer') );
        add_filter('admin_head', array( &$this, 'diskplayer_hide_permalinks' ) );

		// load text domain
		////add_action( 'init', array( &$this, 'plugin_textdomain' ) );

		// add audio_player image sizes
		add_image_size( 'audio-player-thumb', 80, 80, true );

		// set default options
		//add_action( 'after_setup_theme', array( &$this, 'default_options' ) );

		// print CSS style
		add_action('wp_print_styles', array( &$this, 'print_styles_diskplayer' ) );

		// enqueue scripts
		$dplayer_settings = get_option('dplayer_settings');
		$open_scripts_hook = isset($dplayer_settings['open_scripts_hook']) ? $dplayer_settings['open_scripts_hook'] : 'wp_enqueue_scripts';
		add_action($open_scripts_hook, array( &$this, 'enqueue_script_diskplayer') ); //wp_enqueue_scripts | wp_head

		// add shortcode		
		add_shortcode('disk_player', array( &$this, 'shortcode_disk_player') );

		// Add shortcode support for widgets
    	add_filter('widget_text', 'do_shortcode');
        
        // init custom meta box
        //add_action( 'init', array( &$this, 'diskplayer_initialize_cmb_meta_boxes' ) );
        //add_action( 'after_setup_theme', array( &$this, 'diskplayer_initialize_cmb_meta_boxes' ) );

        if ( is_admin() ) {
            
            // init custom meta box
            add_action( 'init', array( &$this, 'diskplayer_initialize_cmb_meta_boxes' ) );

            // add menu page
            add_action( 'admin_menu', array( &$this, 'add_menu' ) );
			
			// action hook to register option settings
            add_action( 'admin_init', array( &$this, 'diskplayer_register_settings' ) );

            // add cols in admin
            add_action( 'admin_init', array( &$this, 'diskplayer_add_custom_cols' ) );

            // duplicate post diskplayer
            add_action( 'admin_init', array( &$this, 'diskplayer_duplicate_post' ) );

            // util scripts
            ////add_action( 'admin_init', array( &$this, 'diskplayer_util_scripts' ) );
        }
	}

	// --------------------------------------------------------------------------

	function activate_diskplayer() {
		//if still not there / important to keep the recorded data after updates
        if( !get_option( "dplayer_settings" ) ) {
            $dplayer_settings_arr = array(
                "open_scripts_hook" => "wp_enqueue_scripts", //wp_enqueue_scripts | wp_head
				"open_scripts_local" => "footer" // header | footer
            );

            //save default option values
            update_option('dplayer_settings', $dplayer_settings_arr);
        }

        // ----------

		//register taxonomies/post types here
        $this->register_post_type_diskplayer();
        flush_rewrite_rules();
	}

    function diskplayer_hide_permalinks() {
        global $post;
        if( !is_object($post) ) return;

        if ($post->post_type == 'diskplayer') {
            echo '<style type="text/css">#edit-slug-box,#view-post-btn,#post-preview,.updated p a{display: none;}</style>';
        }
    }

	// --------------------------------------------------------------------------

	/**
	 * Loads the plugin text domain for translation
	 */
	function plugin_textdomain() {
		$domain = 'dplayer';
		$locale = apply_filters( 'dplayer', get_locale(), $domain );
		load_textdomain( $domain, WP_LANG_DIR.'/'.$domain.'/'.$domain.'-'.$locale.'.mo' );
		load_plugin_textdomain( $domain, FALSE, dirname( plugin_basename( __FILE__ ) ) . '/lang/' );
	} // end plugin_textdomain

	// --------------------------------------------------------------------------

	/**
	 * Print CSS
	 */
	function print_styles_diskplayer() {
		wp_enqueue_style( 'jplayer-dplayer', DISKPLAYER_URL . '/css/jplayer.dplayer.css', array(), '1.0', 'all' );
	}

	// --------------------------------------------------------------------------

	/**
	 * Enqueue scripts
	 */
	function enqueue_script_diskplayer() {
		$dplayer_settings = get_option('dplayer_settings');
		$open_scripts_local = $dplayer_settings['open_scripts_local'] === 'header' ? false : true;

		wp_enqueue_script( 'jquery' );
        wp_enqueue_script( 'disk-player-jplayer', DISKPLAYER_URL . '/js/jquery.jplayer.v2.7.1.min.js', 'jquery', '2.6.4', $open_scripts_local );
		
		//////////////////////
		wp_register_script( 'disk-player-jplayer-playlist', DISKPLAYER_URL . '/js/jplayer.playlist.js', 'jquery', '2.3.0', $open_scripts_local );
		$dp_dir = array( 'disk_player_dir' => DISKPLAYER_URL );
        wp_localize_script( 'disk-player-jplayer-playlist', 'object_diskplayer', $dp_dir );
		wp_enqueue_script( 'disk-player-jplayer-playlist' );
	}

    // --------------------------------------------------------------------------

	/**
	 * util scripts / styles
	 */

    function diskplayer_util_scripts() {
        wp_enqueue_script( 'disk-player-util', DISKPLAYER_URL . '/js/diskplayer.util.js', 'jquery', '1.0', true );
    }


	// --------------------------------------------------------------------------

	/**
	 * shortcode
	 */
	function shortcode_disk_player($atts, $content = null) {

		extract(shortcode_atts(array(
			'id' => 1
		), $atts));

		global $post;
		$querydplayer = new WP_Query( array ('p' => absint($id), 'post_type' => 'diskplayer') );

		if ( $querydplayer->have_posts() ) : while ( $querydplayer->have_posts() ) : $querydplayer->the_post();

			// get settings
			$default_image_poster = trim( get_post_meta($post->ID,'_dplayer_cmb_default_image_poster',true) );
            $display_numbers = get_post_meta($post->ID,'_dplayer_cmb_display_numbers',true == 'on' ) ? 'true' : 'false';
			$display_howmany_items = trim( get_post_meta($post->ID,'_dplayer_cmb_display_howmany_items',true) );
			if ($display_howmany_items == '') $display_howmany_items = 3;
            $autoplay = get_post_meta($post->ID,'_dplayer_cmb_autoplay',true == 'on' ) ? 'true' : 'false';
            $disable_header = get_post_meta($post->ID,'_dplayer_cmb_disable_header',true == 'on' ) ? 'true' : 'false';
            $disable_playlist = get_post_meta($post->ID,'_dplayer_cmb_disable_playlist',true == 'on' ) ? 'true' : 'false';
            $enable_skins = get_post_meta($post->ID,'_dplayer_cmb_enable_skins',true == 'on' ) ? 'true' : 'false';
            $skin = get_post_meta($post->ID,'_dplayer_cmb_skin',true);
        
            // colors/opacity
            $title_icons_color = get_post_meta($post->ID,'_dplayer_cmb_title_icons_color',true);
			$title_icons_color_onhover = get_post_meta($post->ID,'_dplayer_cmb_title_icons_color_onhover',true);
			$font_color = get_post_meta($post->ID,'_dplayer_cmb_font_color',true);
			$sliders_color = get_post_meta($post->ID,'_dplayer_cmb_sliders_color',true);
            $container_border_color = get_post_meta($post->ID,'_dplayer_cmb_container_border_color',true);
            $header_color = get_post_meta($post->ID,'_dplayer_cmb_header_color',true);
            $header_color_opacity = get_post_meta($post->ID,'_dplayer_cmb_header_color_opacity',true);
            $interface_color = get_post_meta($post->ID,'_dplayer_cmb_interface_color',true);
            $interface_color_opacity = get_post_meta($post->ID,'_dplayer_cmb_interface_color_opacity',true);
            $interface_border_color = get_post_meta($post->ID,'_dplayer_cmb_interface_border_color',true);
            $playlist_item_color = get_post_meta($post->ID,'_dplayer_cmb_playlist_item_color',true);
            $playlist_item_color_opacity = get_post_meta($post->ID,'_dplayer_cmb_playlist_item_color_opacity',true);
            $playlist_item_color_onhover = get_post_meta($post->ID,'_dplayer_cmb_playlist_item_color_onhover',true);
            $playlist_item_border_color = get_post_meta($post->ID,'_dplayer_cmb_playlist_item_border_color',true);
            $playlist_current_item_color = get_post_meta($post->ID,'_dplayer_cmb_playlist_current_item_color',true);
            $scrollbar_color = get_post_meta($post->ID,'_dplayer_cmb_scrollbar_color',true);
            $buttons_control_color = get_post_meta($post->ID,'_dplayer_cmb_buttons_control_color',true);
            $toggles_color = get_post_meta($post->ID,'_dplayer_cmb_toggles_color',true);
            $seek_volume_bar = get_post_meta($post->ID,'_dplayer_cmb_seek_volume_bar',true);
            $progress_bar = get_post_meta($post->ID,'_dplayer_cmb_progress_bar',true);
            $other_elem_opacity = get_post_meta($post->ID,'_dplayer_cmb_other_elements_opacity',true);
            $background_image_player = get_post_meta($post->ID,'_dplayer_cmb_background_image_player',true);

			// get tracks
			$trackGroups = get_post_meta($post->ID,'_dplayer_cmb_track_options_group',true);
            ////$trackGroups = array_reverse($trackGroups); //Return an array in the reverse order
			$totalTracks = count($trackGroups);
			//echo count($trackGroups);

		endwhile; else:
			echo '<div>Disk Player Not Found With ID ' . $id . '</div>';
			return;
		endif;
		wp_reset_postdata();

		//enqueue skin

        if ($enable_skins === 'true') {
            if ($skin == 'light') {
                wp_enqueue_style( 'jplayer-dplayer-light', DISKPLAYER_URL . '/css/jplayer.dplayer_light.css', array(), '1.0', 'all' );
            } elseif ($skin == 'dark') {
                wp_enqueue_style( 'jplayer-dplayer-dark', DISKPLAYER_URL . '/css/jplayer.dplayer.css', array(), '1.0', 'all' );
            
            } elseif ($skin == 'grunge') {
                wp_enqueue_style( 'jplayer-dplayer-grunge', DISKPLAYER_URL . '/css/jplayer.dplayer_grunge.css', array(), '1.0', 'all' );
                
            } elseif ($skin == 'stone') {
                wp_enqueue_style( 'jplayer-dplayer-stone', DISKPLAYER_URL . '/css/jplayer.dplayer_stone.css', array(), '1.0', 'all' );
            }
        } else {
            $skin = "dark";
        }


        $header_color_RGB = hex2rgb_dplayer($header_color);
        $header_color_RGBA = "rgba($header_color_RGB,$header_color_opacity)";

        $interface_color_RGB = hex2rgb_dplayer($interface_color);
        $interface_color_RGBA = "rgba($interface_color_RGB,$interface_color_opacity)";

        $plist_color_RGB = hex2rgb_dplayer($playlist_item_color);
        $plist_color_RGBA = "rgba($plist_color_RGB,$playlist_item_color_opacity)";

        $plist_cur_color_RGB = hex2rgb_dplayer($playlist_current_item_color);
        $plist_cur_color_RGBA = "rgba($plist_cur_color_RGB,$playlist_item_color_opacity)";

        $plist_onhover_RGB = hex2rgb_dplayer($playlist_item_color_onhover);
        $plist_onhover_RGBA = "rgba($plist_onhover_RGB,$playlist_item_color_opacity)";

        $btns_control_RGB = hex2rgb_dplayer($buttons_control_color);
        $btns_control_RGBA = "rgba($btns_control_RGB,$other_elem_opacity)";

        $toggles_color_RGB = hex2rgb_dplayer($toggles_color);
        $toggles_color_RGBA = "rgba($toggles_color_RGB,$other_elem_opacity)";

        $scrollbar_RGB = hex2rgb_dplayer($scrollbar_color);
        $scrollbar_RGBA = "rgba($scrollbar_RGB,$other_elem_opacity)";


		$output = '';
		$dp_container = '#disk-player-container_' . $id;
		$output .= '<style type="text/css">';

            //general settings

            if ($disable_playlist === 'true') {
                $output .= $dp_container . ' div.dap-playlist {';
                $output .= 'display:none !important;';
                $output .= '}';
            } else {
                $output .= $dp_container . ' div.dap-playlist {';
                $output .= 'display:block !important;';
                $output .= '}';
            }

            if ($disable_header === 'true') {
                $output .= $dp_container . ' .dap-jplayer {';
                $output .= 'height:0 !important;';
                $output .= 'opacity:0 !important;';
                $output .= '}';

                $output .= $dp_container . ' .dap-jplayer img {';
                $output .= 'display:none !important;';
                $output .= 'height:0 !important;';
                $output .= 'opacity:0 !important;';
                $output .= '}';

                $output .= $dp_container . ' .dplayer-current-track {';
                $output .= 'display:none !important;';
                $output .= '}';
            }

            //colors settings

            if ($enable_skins === 'false') {

                $output .= $dp_container . ' {';
                $output .= 'border:1px solid ' . $container_border_color . ' !important;';

                $output .= 'background-image: url(' . $background_image_player . ');';
                $output .= 'background-repeat: repeat;';

                $output .= '}';

                $output .= $dp_container . ' div.dap-jplayer {';
                $output .= 'background-color:' . $header_color_RGBA . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-interface {';
                $output .= 'background-color:' . $interface_color_RGBA . ' !important;';
                $output .= 'border-top:1px solid ' . $interface_border_color . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-playlist li {';
                $output .= 'background-color:' . $plist_color_RGBA . ' !important;';
                $output .= 'border-top:1px solid ' . $playlist_item_border_color . ';';
                //$output .= 'border-top-color:' . $plist_color_RGBA . ';';
                $output .= '}';
                $output .= $dp_container . ' div.dap-playlist li:hover, ' . $dp_container . ' div.dap-type-playlist div.dap-playlist li.dap-playlist-current:hover {';
                $output .= 'background-color:' . $plist_onhover_RGBA . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-type-playlist div.dap-playlist li.dap-playlist-current {';
                $output .= 'background:' . $plist_cur_color_RGBA . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' .dplayer-scrollbar .scrollbar {';
                $output .= 'background:' . $scrollbar_RGBA . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' .dap-play, ' . $dp_container . ' .dap-pause, ' . $dp_container . ' .dap-previous, ' . $dp_container . ' .dap-next, ' . $dp_container . ' .dap-stop {';
                $output .= 'background-color:' . $btns_control_RGBA . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' ul.dap-toggles {';
                $output .= 'background:' . $toggles_color_RGBA . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-seek-bar, ' . $dp_container . ' div.dap-volume-bar  {';
                $output .= 'background:' . $seek_volume_bar . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-interface a, ' . $dp_container . ' div.dap-interface li a, ' . $dp_container . ' div.dap-type-playlist div.dap-playlist a, ' . $dp_container . ' div.dplayer-current-track .dplayer-title {';
                $output .= 'color:' . $title_icons_color . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-interface a:hover, ' . $dp_container . ' div.dap-type-playlist div.dap-playlist a:hover {';
                $output .= 'color:' . $title_icons_color_onhover . ' !important;';
                $output .= '}';

                $output .= $dp_container . ', ' . $dp_container . ' span.dap-artist, ' . $dp_container . ' span.dap-numbers {';
                $output .= 'color:' . $font_color . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-volume-bar-value, ' .  $dp_container . ' div.dap-play-bar, ' .  $dp_container . ' .dplayer-scrollbar .thumb {';
                $output .= 'background:' . $sliders_color . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-progress {';
                $output .= 'background:' . $progress_bar . ' !important;';
                $output .= '}';
            }
		$output .= '</style>';

		$output .='<div><script type="text/javascript">
				(function($) {
				$(document).ready(function() {
                    var tinyFunctionGlobal;
					var myPlaylist = new jPlayerPlaylist({
						jPlayer: "#jquery_jplayer_' . $id . '",
						cssSelectorAncestor: "#jp_container_' . $id . '"
					}, [';
						//loop all tracks
						for ( $i=0; $i < $totalTracks; $i++) {
							$output .= '{';
							if ( isset($trackGroups[$i]['track_title']) && $trackGroups[$i]['track_title'] != '' ) {
								if ($display_numbers === 'true') {
									if ($i < 9) {
										$number = '0' . ($i + 1) . ': ';
									} else {
										$number = $i + 1 . ': ';
									}
								} else {
									$number = '';
								}
								$output .= 'title:"' . '<span class=\"dap-numbers\">' . $number . '</span>' . $trackGroups[$i]['track_title'] . '",';
							}
							if ( isset($trackGroups[$i]['artist']) && $trackGroups[$i]['artist'] != '' ) {
								$output .= 'artist:"' . $trackGroups[$i]['artist'] . '",';
							}
							if ( isset($trackGroups[$i]['buy_url']) && $trackGroups[$i]['buy_url'] != '' ) {
                                $trackGroups[$i]['buy_text'] = isset($trackGroups[$i]['buy_text']) ? $trackGroups[$i]['buy_text'] : "";
								$output .= 'cart:["' . esc_url($trackGroups[$i]['buy_url']) . '","' . $trackGroups[$i]['buy_text'] . '"],';
							}
							if ( isset($trackGroups[$i]['download_url']) && $trackGroups[$i]['download_url'] != '' ) {
                                $trackGroups[$i]['download_text'] = isset($trackGroups[$i]['download_text']) ? $trackGroups[$i]['download_text'] : "";
								$output .= 'download:["' . esc_url($trackGroups[$i]['download_url']) . '","' . $trackGroups[$i]['download_text'] . '"],';
							}
							if ( isset($trackGroups[$i]['extra_info_url']) && $trackGroups[$i]['extra_info_url'] != '' ) {
                                $trackGroups[$i]['extra_info_text'] = isset($trackGroups[$i]['extra_info_text']) ? $trackGroups[$i]['extra_info_text'] : "";
								$output .= 'extrainfo:["' . esc_url($trackGroups[$i]['extra_info_url']) . '","' . $trackGroups[$i]['extra_info_text'] . '"],';
							}
							$output .= 'mp3:"' . esc_url($trackGroups[$i]['mp3_file']) . '",';
							$output .= 'oga:"' . esc_url($trackGroups[$i]['mp3_file']) . '",';

							$poster_image = ( isset($trackGroups[$i]['poster_image']) && $trackGroups[$i]['poster_image'] != '' ) ? $trackGroups[$i]['poster_image'] : $default_image_poster;
							$output .= 'poster:"' . esc_url($poster_image) . '"';
							$output .= '},';
						}//for
                        //////////////////////////
                        $ua = $_SERVER["HTTP_USER_AGENT"]; // Get user-agent of browser
						require_once( 'includes/get_browser.php' );
						$browser = getBrowser();
						//echo $browser['name'] . " | " . $browser['version'] . " | " . $browser['platform'] . "<br>";
						//print_r($browser);
						$is_safari = strpos($browser['name'], 'Safari') ? true : false;
						
						if( $is_safari && (int)$browser['version'] < 6 ) { 
                            $solutionHtmlFlash = "flash, html";
                        } else {
                            $solutionHtmlFlash = "html, flash";
                        }
					$output .= 
					'], {
						swfPath: "' . DISKPLAYER_URL . '/js",
						solution: "' . $solutionHtmlFlash . '", //test if the swfPath is correct ( "flash, html" )
						supplied: "mp3,oga",
						wmode: "window",
						smoothPlayBar: true,
						keyEnabled: true,
						preload: "none",
						size: {
							width: "80",
							height: "110", //80 + margin
							cssClass: ""
						},
						audioFullScreen: false //Allows the audio poster to go full screen via keyboard
					});
					// ----- get current track - //event.play
					$("#jquery_jplayer_' . $id . '").bind($.jPlayer.event.play, function(event) {
                        var current = myPlaylist.current;
                        /////tinyFunctionGlobal(current);
                        if ($.isFunction(tinyFunctionGlobal)) {
                        	tinyFunctionGlobal(current);
			             }
						$("#dplayer-current-track_' . $id . ' .dplayer-title, #dplayer-current-track_' . $id . ' .dplayer-artist").empty();
						$("#dplayer-current-track_' . $id . ' .dplayer-title").prepend(myPlaylist.playlist[myPlaylist.current].title);
						$("#dplayer-current-track_' . $id . ' .dplayer-artist").prepend(myPlaylist.playlist[myPlaylist.current].artist);
					});
					//event.ready
					$("#jquery_jplayer_' . $id . '").bind($.jPlayer.event.ready, function(event) {
						$("#dplayer-current-track_' . $id . ' div").empty();
						$("#dplayer-current-track_' . $id . ' .dplayer-title").append(myPlaylist.playlist[myPlaylist.current].title);
						$("#dplayer-current-track_' . $id . ' .dplayer-artist").append(myPlaylist.playlist[myPlaylist.current].artist);';
                        if ($autoplay === 'true') {
                            $output .= '$("#jquery_jplayer_' . $id . '").jPlayer("play");';
                        }
                    $output .= '
					});
					// ----- scrollbar ---------
                    $(window).load({noncache: new Date().getTime()},function() {
                        var tinyScrollbarEvent;
                        var displayHowmanyItems = "' . $display_howmany_items . '";
                        var thumbClick;
                        setTimeout(function(){ 
                            var $tinyScrollbar = $("#scrollbar' . $id . '").tinyscrollbar( { thumbSize: 25, axis: "y", wheel:false } );
                            /////////////////////////
                            tinyScrollbarEvent = $tinyScrollbar.data("plugin_tinyscrollbar");
                            tinyFunctionGlobal = function(theIndex) {
                                ////////////////////////////////
                                var trackCurrentHeight = 0;
                                var tracksTotalHeight = 0;
                                var $scrollbar = $("#scrollbar' . $id . '");
                                var itemsTracks = $("#scrollbar' . $id . ' li"); //.length
                                $(itemsTracks).each(function(i) {
                                    if (i < theIndex) {
                                        trackCurrentHeight += $(this).height() + parseInt($(this).css("paddingTop")) * 2;
                                    }
                                    tracksTotalHeight += $(this).height() + parseInt($(this).css("paddingTop")) * 2;
                                });
                                var viewportHeight = $("#scrollbar' . $id . ' .viewport").height();
                                var h = $("#scrollbar' . $id . ' li").eq(theIndex).height();
                                var pad = $("#scrollbar' . $id . ' li").eq(theIndex).css("paddingTop");
                                pad = parseInt(pad) * 2;
                                ////alert(tracksTotalHeight + " | " + trackCurrentHeight + " | " + viewportHeight);
                                if (tracksTotalHeight - trackCurrentHeight + (h + pad) > viewportHeight) {
                                    tinyScrollbarEvent.update(trackCurrentHeight + (theIndex+1) - 1);
                                }
                                var $thumbScrollbar = $scrollbar.find(".track-dplayer .thumb");
                                if ( ($thumbScrollbar.offset().top + $thumbScrollbar.height()) > ($scrollbar.offset().top + $scrollbar.height()) ) {
                                    $thumbScrollbar.css({ top: $scrollbar.height() - $thumbScrollbar.height() });
                                }
                            }
                        }, 2500);
                    });
					// -------------------------
                    // ----- parent container // hide volume
                    var isTouch = "ontouchstart" in window || "onmsgesturechange" in window ? true : false;
                    ////if (!isTouch) {                        
                        var $container = $( "' . $dp_container . '" );
                        var $id = "' .  $id . '";
                        $(window).on("resize", function(e) {
                        //$container.bind("resize", function(e) {
                            var parentWidth = $container.parent().width();
							//alert(parentWidth + " - " + $container.width());
                            if (parentWidth < 480) {
                                $container.find(".dap-volume-max, .dap-volume-bar, .dap-mute").hide();
                                if (parentWidth < 300) {
                                    //console.log("yyy");
                                    //margin 0 to ul.dap-controls
                                    $container.find(".dap-interface ul.dap-controls").css( { marginLeft: 0 } );
                                    $container.find("ul.dap-toggles").hide();
                                } else {
                                    //margin 0 to ul.dap-controls
                                    $container.find(".dap-interface ul.dap-controls").css( { marginLeft: 80 } );
                                    $container.find("ul.dap-toggles").show();
                                }
                            } else {
                                $container.find(".dap-volume-max, .dap-volume-bar, .dap-mute").show();
                            }
                        });//resize
                        setTimeout(function(){ $container.trigger("resize") }, 1000);
                    ////}
                    // -------------------------
				});//ready
				})(jQuery);
			</script></div>';

		$output .= '
			<div id="disk-player-container_' . $id . '" class="disk-player-container ' . $skin . '">

				<div id="jquery_jplayer_' . $id . '" class="dap-jplayer"></div>

				<div id="dplayer-current-track_' . $id . '" class="dplayer-current-track">
					<div class="dplayer-title"></div>
					<div class="dplayer-artist"></div>
				</div>

				<div id="jp_container_' . $id . '" class="dap-audio">
					<div class="dap-type-playlist">
						<div class="dap-gui dap-interface">
							<ul class="dap-controls">
								<li><a href="javascript:;" class="dap-previous" tabindex="1"></a></li>
								<li><a href="javascript:;" class="dap-play" tabindex="1"></a></li>
								<li><a href="javascript:;" class="dap-pause" tabindex="1"></a></li>
								<li><a href="javascript:;" class="dap-next" tabindex="1"></a></li>
								<li><a href="javascript:;" class="dap-stop" tabindex="1"></a></li>
								<li><a href="javascript:;" class="dap-mute" tabindex="1" title="mute"></a></li>
								<li><a href="javascript:;" class="dap-unmute" tabindex="1" title="unmute"></a></li>
								<li><a href="javascript:;" class="dap-volume-max" tabindex="1" title="max volume"></a></li>
							</ul>
							<div class="dap-progress">
								<div class="dap-seek-bar">
									<div class="dap-play-bar"></div>
								</div>
							</div>
							<div class="dap-volume-bar">
								<div class="dap-volume-bar-value"></div>
							</div>
							<div class="dap-time-holder">
								<div class="dap-current-time"></div>
								<div class="dap-duration"></div>
							</div>
							<ul class="dap-toggles">
								<li><a href="javascript:;" class="dap-shuffle" tabindex="1" title="shuffle"></a></li>
								<li><a href="javascript:;" class="dap-shuffle-off" tabindex="1" title="shuffle off"></a></li>
								<li><a href="javascript:;" class="dap-repeat" tabindex="1" title="repeat"></a></li>
								<li><a href="javascript:;" class="dap-repeat-off" tabindex="1" title="repeat off"></a></li>
							</ul>
						</div>';

						if ($display_howmany_items >= $totalTracks) {
							$paddingRight = 0;
						} else {
							$paddingRight = '18px';
						}

						$output .= '
						<div id="scrollbar' . $id . '" class="dap-playlist dplayer-scrollbar ' . $skin . '" style="padding-right:' . $paddingRight . '">

							<div class="scrollbar"><div class="track-dplayer"><div id="thumb_' . $id . '" class="thumb"></div></div></div>';

							////echo $display_howmany_items . ' | ' . $totalTracks . '<br>';

							if ($totalTracks < $display_howmany_items) {
								$display_howmany_items = $totalTracks;
							}
                            
                            $viewportHeightSum = ( $display_howmany_items * 35 + round($display_howmany_items/2) );
							$viewportHeight = $viewportHeightSum . 'px;';
                            //$viewportHeight = $display_howmany_items * 35 + $display_howmany_items . 'px;';

							$output .= '
							<div class="viewport" style="height:' . $viewportHeight . '">
								<div class="overview">
									<ul class="">
										<li></li>
									</ul>
								</div><!-- ./overview -->
							</div><!-- ./viewport -->
						</div><!-- ./dap-playlist -->

						<div class="dap-no-solution">
							<span>Update Required</span>
							To play the media you will need to either update your browser to a recent version or update your <a href="http://get.adobe.com/flashplayer/" target="_blank">Flash plugin</a>.
						</div>
					</div>
				</div>

			</div><!-- /.disk-player-container -->
		';

		return $output;

	}//shortcode

	// --------------------------------------------------------------------------

	/**
	 * Register post type
	 */
	function register_post_type_diskplayer() {

		$labels = array( 
			'name' => _x( 'Disk Players', 'dplayer' ),
			'singular_name' => _x( 'Disk Player', 'dplayer' ),
			'add_new' => _x( 'Add New', 'dplayer' ),
			'add_new_item' => _x( 'Add New Disk Player', 'dplayer' ),
			'all_items'  =>  _x( 'Disk Players', 'dplayer' ),
			'edit_item' => _x( 'Edit Disk Player', 'dplayer' ),
			'new_item' => _x( 'New Disk Player', 'dplayer' ),
			'view_item' => _x( 'View Disk Player', 'dplayer' ),
			'search_items' => _x( 'Search Disk Players', 'dplayer' ),
			'not_found' => _x( 'No disk player found', 'dplayer' ),
			'not_found_in_trash' => _x( 'No disk players found in Trash', 'dplayer' ),
			'parent_item_colon' => '',
			'menu_name' => _x( 'Disk Player', 'dplayer' ),
		);

		$args = array(
			'labels' => $labels,
			'public' => true,
			'publicly_queryable' => true,
			'show_ui' => true,
			'show_in_menu' => true,
			'query_var' => false,
			'rewrite' => array( 'slug' => __('diskplayer', 'dplayer') ),
			'capability_type' => 'post',
			'has_archive' => false,
			'hierarchical' => false,
			'menu_position' => 5.3,
			'taxonomies' => array(),
			'supports' => array( 'title' ),
			'exclude_from_search' => true,
			'description' => 'Present your soundtracks',
			'menu_icon' => DISKPLAYER_URL . '/img/menu.png',
		);

		register_post_type( 'diskplayer', $args );
	}


	// --------------------------------------------------------------------------


    /**
	 * Add MetaBox
	 */

	function diskplayer_initialize_cmb_meta_boxes() {    
		if ( !class_exists( 'cmb_Meta_Box_Diskplayer' ) ) {
			require_once( 'includes/metabox-functions.php' );
			require_once( 'includes/metabox/init.php' );
		}
	}

	/**
	 * Add cols post type
	 */

	function diskplayer_add_custom_cols() {

		function diskplayer_AddThumbColumn($cols) { 
			$cols['thumbnail'] = __('Thumbnail');
			return $cols;
		}
		function diskplayer_AddThumbValue($column_name, $post_id) {

			// avoids duplicate thumbnails
			global $typenow;

			if ($typenow == 'diskplayer' && 'thumbnail' == $column_name) {

				$thumbnail_id = get_post_meta( $post_id, '_dplayer_cmb_default_image_poster_id', true );

				if ($thumbnail_id) {
					//$thumb = wp_get_attachment_image( $thumbnail_id, array(60, 60), true );
                    $thumb = wp_get_attachment_image( $thumbnail_id, array(60, 60), false );
				}

				if ( isset($thumb) && $thumb ) {
					echo $thumb;
				} else {
					echo __('None','dplayer');
				}
			}
		}


		function diskplayer_AddShortcodeColumn($cols) { 
			$cols['shortcode_name'] = __('Shortcode');
			return $cols;
		}
		function diskplayer_getpostid($column_name, $post_ID) {
			global $post;
			if ($column_name == 'shortcode_name') {
				// show content of 'shortcode_name' column
				$shorcode_value = '[disk_player id="' . $post_ID . '"]';
				echo "<input type='text' name='disk_player_shortcode' value='$shorcode_value' />";
			}
		}

		function diskplayer_edit_columns($columns) {
			$columns = array(
				"cb" => "<input type=\"checkbox\" />",
				"title" => __('Title', 'dplayer'), 
				"thumbnail" => __('Thumbnail', 'dplayer'),
				"shortcode_name" => __('Shortcode', 'dplayer'), 
				"author" => __('Author', 'dplayer'), 
				//"description" => __('Description', 'dplayer'),
				"date" => __('Date', 'dplayer')
			);
			return $columns;
		}

		//add thumbnail to diskplayer post type in admin
		add_filter( 'manage_diskplayer_posts_columns', 'diskplayer_AddThumbColumn' );
		add_action( 'manage_posts_custom_column', 'diskplayer_AddThumbValue', 10, 2 );
		add_filter( 'manage_diskplayer_posts_columns', 'diskplayer_AddShortcodeColumn' );
		add_action('manage_diskplayer_posts_custom_column', 'diskplayer_getpostid', 10, 2);
		add_filter("manage_edit-diskplayer_columns", "diskplayer_edit_columns"); //order columns

	}//diskplayer_add_custom_cols


	// --------------------------------------------------------------------------


	/**
	 * Add options sub-menu
	 */
	function add_menu() {
		//help
		add_submenu_page( 'edit.php?post_type=diskplayer', __( 'Help', 'dplayer' ), __( 'Help', 'dplayer' ), 'administrator', 'dplayer-help', array( &$this, 'help_page' ) );
		
		//settings
		add_submenu_page( 'edit.php?post_type=diskplayer', __( 'Settings', 'dplayer' ), __( 'Settings', 'dplayer' ), 'administrator', 'dplayer-settings-fields', array( &$this, 'settings_page' ) );
	}
	
	function diskplayer_register_settings() {
        //register Array of settings
        register_setting( 'dplayer-settings-fields', 'dplayer_settings' );
    }

	// --------------------------------------------------------------------------

	/**
	 * help page
	 */
	function help_page() {
        require_once( 'includes/help.php' );
	}
	
	// --------------------------------------------------------------------------

	/**
	 * settings page
	 */
	function settings_page() {
        require_once( 'includes/settings.php' );
	}


    // --------------------------------------------------------------------------

    /*
     * Function duplicate post diskplayer
     */

    function diskplayer_duplicate_post(){

        //Function creates post duplicate as a draft and redirects then to the diskplayer list

        function dplayer_duplicate_post_as_draft(){
            global $wpdb;
            if (! ( isset( $_GET['post']) || isset( $_POST['post'])  || ( isset($_REQUEST['action']) && 'dplayer_duplicate_post_as_draft' == $_REQUEST['action'] ) ) ) {
                wp_die('No post to duplicate has been supplied!');
            }

            //get the original post id
            $post_id = (isset($_GET['post']) ? $_GET['post'] : $_POST['post']);

            //and all the original post data then
            $post = get_post( $post_id );

            //if you don't want current user to be the new post author,
            //then change next couple of lines to this: $new_post_author = $post->post_author;
            $current_user = wp_get_current_user();
            $new_post_author = $current_user->ID;

            //if post data exists, create the post duplicate
            if (isset( $post ) && $post != null) {

                //new post data array
                $args = array(
                    'comment_status' => $post->comment_status,
                    'ping_status'    => $post->ping_status,
                    'post_author'    => $new_post_author,
                    'post_content'   => $post->post_content,
                    'post_excerpt'   => $post->post_excerpt,
                    'post_name'      => $post->post_name,
                    'post_parent'    => $post->post_parent,
                    'post_password'  => $post->post_password,
                    'post_status'    => 'draft',
                    'post_title'     => $post->post_title . ' Copy',
                    'post_type'      => $post->post_type,
                    'to_ping'        => $post->to_ping,
                    'menu_order'     => $post->menu_order
                );

                //insert the post by wp_insert_post() function
                $new_post_id = wp_insert_post( $args );

                //get all current post terms ad set them to the new post draft
                $taxonomies = get_object_taxonomies($post->post_type); // returns array of taxonomy names for post type, ex array("category", "post_tag");
                foreach ($taxonomies as $taxonomy) {
                    $post_terms = wp_get_object_terms($post_id, $taxonomy, array('fields' => 'slugs'));
                    wp_set_object_terms($new_post_id, $post_terms, $taxonomy, false);
                }

                //duplicate all post meta
                $post_meta_infos = $wpdb->get_results("SELECT meta_key, meta_value FROM $wpdb->postmeta WHERE post_id=$post_id");
                if (count($post_meta_infos)!=0) {
                    $sql_query = "INSERT INTO $wpdb->postmeta (post_id, meta_key, meta_value) ";
                    foreach ($post_meta_infos as $meta_info) {
                        $meta_key = $meta_info->meta_key;
                        $meta_value = addslashes($meta_info->meta_value);
                        $sql_query_sel[]= "SELECT $new_post_id, '$meta_key', '$meta_value'";
                    }
                    $sql_query.= implode(" UNION ALL ", $sql_query_sel);
                    $wpdb->query($sql_query);
                }

                //redirect to the edit post screen for the new draft
                //wp_redirect( admin_url( 'post.php?action=edit&post=' . $new_post_id ) );

                //redirect to diskplayer list
                wp_redirect( admin_url( 'edit.php?post_type=diskplayer' ) );

                exit;
            } else {
                wp_die('Post creation failed, could not find original post: ' . $post_id);
            }
        }
        add_action( 'admin_action_dplayer_duplicate_post_as_draft', 'dplayer_duplicate_post_as_draft' );


        //Add the duplicate link to action list for post_row_actions
        function dplayer_duplicate_post_link( $actions, $post ) { 
            //When using custom post type use the post_row_actions filter hook and check the post type to modify it only
            if ($post->post_type == "diskplayer") {
                if (current_user_can('edit_posts')) {
                    $actions['duplicate'] = '<a href="admin.php?action=dplayer_duplicate_post_as_draft&amp;post=' . $post->ID . '" title="Duplicate this item" rel="permalink">Duplicate</a>';
                }
            }
            return $actions;
        }
        ////add_filter('{post type name}_row_actions', 'dplayer_duplicate_post_link', 10, 2);
        add_filter( 'post_row_actions', 'dplayer_duplicate_post_link', 10, 2 );

    }//diskplayer_duplicate_post

} // end class
endif;

$disk_player = new Disk_Player;



if( ! function_exists( 'hex2rgb_dplayer' ) ):
/**
 * Returns rgb color
 */
function hex2rgb_dplayer($hex) {
   $hex = str_replace("#", "", $hex);

   if(strlen($hex) == 3) {
      $r = hexdec(substr($hex,0,1).substr($hex,0,1));
      $g = hexdec(substr($hex,1,1).substr($hex,1,1));
      $b = hexdec(substr($hex,2,1).substr($hex,2,1));
   } else {
      $r = hexdec(substr($hex,0,2));
      $g = hexdec(substr($hex,2,2));
      $b = hexdec(substr($hex,4,2));
   }
   $rgb = array($r, $g, $b);
   return implode(",", $rgb); // returns the rgb values separated by commas
   ////return $rgb; // returns an array with the rgb values
}
endif;